# -*- coding: utf-8 -*-
from PyQt4 import QtGui, QtCore

_encoding = QtGui.QApplication.UnicodeUTF8

def _translate(context, text, disambig):
    return QtGui.QApplication.translate(context, text, disambig, _encoding)

class ClicLabel(QtGui.QLabel):    
    clicked = QtCore.pyqtSignal()  
    
    def __init(self, parent):
        QtGui.QLabel.__init__(self, parent) 
        
    def mouseReleaseEvent(self, ev):
        self.clicked.emit()


class PopUpButton(ClicLabel):
    
    currentItemChanged = QtCore.pyqtSignal(int)
    
    def __init__(self,parent, itemsList, size = 48, direction = 'bottom'):
        ClicLabel.__init__(self)
        self.resize(size,size)   
        self.direction = direction
        self.itemsList =  itemsList
        self.setFrameShape(QtGui.QFrame.StyledPanel)
        self.setFrameShadow(QtGui.QFrame.Raised)
        self.popup = PopupWidget(self, self.itemsList, direction = direction)
        self.set_pixmap(0)
    
    def mousePressEvent(self, event):
        
        if self.direction == 'right' :
            point = self.rect().topRight()
            global_point = self.mapToGlobal(point)
            self.popup.move(global_point)
        else :
            point = self.rect().bottomLeft()
            global_point = self.mapToGlobal(point)
            self.popup.move(global_point)
        self.popup.show()
        self.setFocus(True)
        
    def set_pixmap(self,item):
        self.current_item = item
        self.currentItemChanged.emit(item)
        icon = self.itemsList[item]
        if isinstance(icon, QtCore.QFile) :
            pixmap = QtGui.QPixmap(icon.fileName())
            self.setPixmap(pixmap)
        elif isinstance(icon, str) or isinstance(icon, unicode):
            self.setText(icon)
            
    def currentItem(self):
        return self.current_item


class PopupWidget(QtGui.QWidget):

    def __init__(self, parent, itemsList, direction = 'bottom'):
        super(PopupWidget, self).__init__()
        self.setWindowFlags(QtCore.Qt.Popup)
        #self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
        self.parent = parent
        self.direction = direction
        self.layout = QtGui.QGridLayout(self)
        self.layout.setMargin(0)
        self.layout.setSpacing(1)            
        
        for pos,item in enumerate(itemsList) :
            label = ClicLabel()
            label.setFixedSize(self.parent.size())
            label.setAlignment(QtCore.Qt.AlignCenter)
            label.setFrameShape(QtGui.QLabel.StyledPanel)
            label.setFrameShadow(QtGui.QLabel.Raised)
            if isinstance(item, QtCore.QFile) :
                pixmap = QtGui.QPixmap(item.fileName())
                label.setPixmap(pixmap)
            elif isinstance(item, str) or isinstance(item, unicode):
                label.setText(item)
            label.clicked.connect(self.buttonClicked)
            if self.direction == 'right' :
                self.layout.addWidget(label, 0, pos) 
            else :
                self.layout.addWidget(label, pos,0)


    def buttonClicked(self):
        self.button = self.sender()
        idx = self.layout.indexOf(self.button)
        location = self.layout.getItemPosition(idx)
        #print "Button", self.button, "at row/col", location[:2]
        if self.direction == 'right' :
            item = location[:2][1]
        else :
            item = location[:2][0]
        self.parent.set_pixmap(item)
        self.parent.popup.hide()


class AxisButton(PopUpButton):    
    itemsList = [QtCore.QFile('../data/icones/axe11.svg'),QtCore.QFile('../data/icones/axe01.svg'),QtCore.QFile('../data/icones/axe10.svg'),QtCore.QFile('../data/icones/axe00.svg')]
    
    def __init__(self, parent):
        PopUpButton.__init__(self, parent, self.itemsList, direction = 'right')


class RefButton(PopUpButton):    
    defaultItemsList = [QtCore.QFile('../data/icones/ref-camera.svg')]
    
    def __init__(self, parent, points = 2):
        self.parent = parent
        self.itemsList = self.defaultItemsList[:]
        self.create_buttons(points)
        
    def create_buttons(self, points):        
        for i in range(points):
            self.itemsList.append(u"Point\n n°{}".format(i+1))
        PopUpButton.__init__(self, self.parent, self.itemsList, direction = 'bottom')
 
    def setPoints(self, nb):
        self.itemsList = self.defaultItemsList[:]
        self.create_buttons(nb)

if __name__ == '__main__':
    import sys
    app = QtGui.QApplication(sys.argv)
    window = RefButton(None,2)
    window.setPoints(3)
    window.show()
    sys.exit(app.exec_()) 
